@@ -238,7 +238,11 @@ c          energy / nucleon for heavy
 
       if(ThinSampling) then
 c           thin sampling
-           Ethin = EthinRatio*ergpn
+         if(EthinRatio .lt. 0.) then
+            Ethin = -EthinRatio
+         else
+            Ethin = EthinRatio*ergpn
+         endif
       else
            Ethin = 0.
       endif
